# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `QuantumDef.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if 'QuantumDef' not in _M_omero.model.__dict__:
    _M_omero.model.QuantumDef = Ice.createTempClass()
    class QuantumDef(_M_omero.model.IObject):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _cdStart=None, _cdEnd=None, _bitResolution=None):
            if Ice.getType(self) == _M_omero.model.QuantumDef:
                raise RuntimeError('omero.model.QuantumDef is an abstract class')
            _M_omero.model.IObject.__init__(self, _id, _details, _loaded)
            self._version = _version
            self._cdStart = _cdStart
            self._cdEnd = _cdEnd
            self._bitResolution = _bitResolution

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::IObject', '::omero::model::QuantumDef')

        def ice_id(self, current=None):
            return '::omero::model::QuantumDef'

        def ice_staticId():
            return '::omero::model::QuantumDef'
        ice_staticId = staticmethod(ice_staticId)

        def getVersion(self, current=None):
            pass

        def setVersion(self, theVersion, current=None):
            pass

        def getCdStart(self, current=None):
            pass

        def setCdStart(self, theCdStart, current=None):
            pass

        def getCdEnd(self, current=None):
            pass

        def setCdEnd(self, theCdEnd, current=None):
            pass

        def getBitResolution(self, current=None):
            pass

        def setBitResolution(self, theBitResolution, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_QuantumDef)

        __repr__ = __str__

    _M_omero.model.QuantumDefPrx = Ice.createTempClass()
    class QuantumDefPrx(_M_omero.model.IObjectPrx):

        def getVersion(self, _ctx=None):
            return _M_omero.model.QuantumDef._op_getVersion.invoke(self, ((), _ctx))

        def begin_getVersion(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.QuantumDef._op_getVersion.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getVersion(self, _r):
            return _M_omero.model.QuantumDef._op_getVersion.end(self, _r)

        def setVersion(self, theVersion, _ctx=None):
            return _M_omero.model.QuantumDef._op_setVersion.invoke(self, ((theVersion, ), _ctx))

        def begin_setVersion(self, theVersion, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.QuantumDef._op_setVersion.begin(self, ((theVersion, ), _response, _ex, _sent, _ctx))

        def end_setVersion(self, _r):
            return _M_omero.model.QuantumDef._op_setVersion.end(self, _r)

        def getCdStart(self, _ctx=None):
            return _M_omero.model.QuantumDef._op_getCdStart.invoke(self, ((), _ctx))

        def begin_getCdStart(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.QuantumDef._op_getCdStart.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getCdStart(self, _r):
            return _M_omero.model.QuantumDef._op_getCdStart.end(self, _r)

        def setCdStart(self, theCdStart, _ctx=None):
            return _M_omero.model.QuantumDef._op_setCdStart.invoke(self, ((theCdStart, ), _ctx))

        def begin_setCdStart(self, theCdStart, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.QuantumDef._op_setCdStart.begin(self, ((theCdStart, ), _response, _ex, _sent, _ctx))

        def end_setCdStart(self, _r):
            return _M_omero.model.QuantumDef._op_setCdStart.end(self, _r)

        def getCdEnd(self, _ctx=None):
            return _M_omero.model.QuantumDef._op_getCdEnd.invoke(self, ((), _ctx))

        def begin_getCdEnd(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.QuantumDef._op_getCdEnd.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getCdEnd(self, _r):
            return _M_omero.model.QuantumDef._op_getCdEnd.end(self, _r)

        def setCdEnd(self, theCdEnd, _ctx=None):
            return _M_omero.model.QuantumDef._op_setCdEnd.invoke(self, ((theCdEnd, ), _ctx))

        def begin_setCdEnd(self, theCdEnd, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.QuantumDef._op_setCdEnd.begin(self, ((theCdEnd, ), _response, _ex, _sent, _ctx))

        def end_setCdEnd(self, _r):
            return _M_omero.model.QuantumDef._op_setCdEnd.end(self, _r)

        def getBitResolution(self, _ctx=None):
            return _M_omero.model.QuantumDef._op_getBitResolution.invoke(self, ((), _ctx))

        def begin_getBitResolution(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.QuantumDef._op_getBitResolution.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getBitResolution(self, _r):
            return _M_omero.model.QuantumDef._op_getBitResolution.end(self, _r)

        def setBitResolution(self, theBitResolution, _ctx=None):
            return _M_omero.model.QuantumDef._op_setBitResolution.invoke(self, ((theBitResolution, ), _ctx))

        def begin_setBitResolution(self, theBitResolution, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.QuantumDef._op_setBitResolution.begin(self, ((theBitResolution, ), _response, _ex, _sent, _ctx))

        def end_setBitResolution(self, _r):
            return _M_omero.model.QuantumDef._op_setBitResolution.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.QuantumDefPrx.ice_checkedCast(proxy, '::omero::model::QuantumDef', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.QuantumDefPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::QuantumDef'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_QuantumDefPrx = IcePy.defineProxy('::omero::model::QuantumDef', QuantumDefPrx)

    _M_omero.model._t_QuantumDef = IcePy.declareClass('::omero::model::QuantumDef')

    _M_omero.model._t_QuantumDef = IcePy.defineClass('::omero::model::QuantumDef', QuantumDef, -1, (), True, False, _M_omero.model._t_IObject, (), (
        ('_version', (), _M_omero._t_RInt, False, 0),
        ('_cdStart', (), _M_omero._t_RInt, False, 0),
        ('_cdEnd', (), _M_omero._t_RInt, False, 0),
        ('_bitResolution', (), _M_omero._t_RInt, False, 0)
    ))
    QuantumDef._ice_type = _M_omero.model._t_QuantumDef

    QuantumDef._op_getVersion = IcePy.Operation('getVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    QuantumDef._op_setVersion = IcePy.Operation('setVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    QuantumDef._op_getCdStart = IcePy.Operation('getCdStart', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    QuantumDef._op_setCdStart = IcePy.Operation('setCdStart', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    QuantumDef._op_getCdEnd = IcePy.Operation('getCdEnd', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    QuantumDef._op_setCdEnd = IcePy.Operation('setCdEnd', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    QuantumDef._op_getBitResolution = IcePy.Operation('getBitResolution', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    QuantumDef._op_setBitResolution = IcePy.Operation('setBitResolution', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())

    _M_omero.model.QuantumDef = QuantumDef
    del QuantumDef

    _M_omero.model.QuantumDefPrx = QuantumDefPrx
    del QuantumDefPrx

# End of module omero.model

__name__ = 'omero'

# End of module omero
