# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `Job.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'JobStatus' not in _M_omero.model.__dict__:
    _M_omero.model._t_JobStatus = IcePy.declareClass('::omero::model::JobStatus')
    _M_omero.model._t_JobStatusPrx = IcePy.declareProxy('::omero::model::JobStatus')

if 'JobOriginalFileLink' not in _M_omero.model.__dict__:
    _M_omero.model._t_JobOriginalFileLink = IcePy.declareClass('::omero::model::JobOriginalFileLink')
    _M_omero.model._t_JobOriginalFileLinkPrx = IcePy.declareProxy('::omero::model::JobOriginalFileLink')

if 'OriginalFile' not in _M_omero.model.__dict__:
    _M_omero.model._t_OriginalFile = IcePy.declareClass('::omero::model::OriginalFile')
    _M_omero.model._t_OriginalFilePrx = IcePy.declareProxy('::omero::model::OriginalFile')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if '_t_JobOriginalFileLinksSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_JobOriginalFileLinksSeq = IcePy.defineSequence('::omero::model::JobOriginalFileLinksSeq', (), _M_omero.model._t_JobOriginalFileLink)

if '_t_JobLinkedOriginalFileSeq' not in _M_omero.model.__dict__:
    _M_omero.model._t_JobLinkedOriginalFileSeq = IcePy.defineSequence('::omero::model::JobLinkedOriginalFileSeq', (), _M_omero.model._t_OriginalFile)

if 'Job' not in _M_omero.model.__dict__:
    _M_omero.model.Job = Ice.createTempClass()
    class Job(_M_omero.model.IObject):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _username=None, _groupname=None, _type=None, _message=None, _status=None, _submitted=None, _scheduledFor=None, _started=None, _finished=None, _originalFileLinksSeq=None, _originalFileLinksLoaded=False, _originalFileLinksCountPerOwner=None):
            if Ice.getType(self) == _M_omero.model.Job:
                raise RuntimeError('omero.model.Job is an abstract class')
            _M_omero.model.IObject.__init__(self, _id, _details, _loaded)
            self._version = _version
            self._username = _username
            self._groupname = _groupname
            self._type = _type
            self._message = _message
            self._status = _status
            self._submitted = _submitted
            self._scheduledFor = _scheduledFor
            self._started = _started
            self._finished = _finished
            self._originalFileLinksSeq = _originalFileLinksSeq
            self._originalFileLinksLoaded = _originalFileLinksLoaded
            self._originalFileLinksCountPerOwner = _originalFileLinksCountPerOwner

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::IObject', '::omero::model::Job')

        def ice_id(self, current=None):
            return '::omero::model::Job'

        def ice_staticId():
            return '::omero::model::Job'
        ice_staticId = staticmethod(ice_staticId)

        def getVersion(self, current=None):
            pass

        def setVersion(self, theVersion, current=None):
            pass

        def getUsername(self, current=None):
            pass

        def setUsername(self, theUsername, current=None):
            pass

        def getGroupname(self, current=None):
            pass

        def setGroupname(self, theGroupname, current=None):
            pass

        def getType(self, current=None):
            pass

        def setType(self, theType, current=None):
            pass

        def getMessage(self, current=None):
            pass

        def setMessage(self, theMessage, current=None):
            pass

        def getStatus(self, current=None):
            pass

        def setStatus(self, theStatus, current=None):
            pass

        def getSubmitted(self, current=None):
            pass

        def setSubmitted(self, theSubmitted, current=None):
            pass

        def getScheduledFor(self, current=None):
            pass

        def setScheduledFor(self, theScheduledFor, current=None):
            pass

        def getStarted(self, current=None):
            pass

        def setStarted(self, theStarted, current=None):
            pass

        def getFinished(self, current=None):
            pass

        def setFinished(self, theFinished, current=None):
            pass

        def unloadOriginalFileLinks(self, current=None):
            pass

        def sizeOfOriginalFileLinks(self, current=None):
            pass

        def copyOriginalFileLinks(self, current=None):
            pass

        def addJobOriginalFileLink(self, target, current=None):
            pass

        def addAllJobOriginalFileLinkSet(self, targets, current=None):
            pass

        def removeJobOriginalFileLink(self, theTarget, current=None):
            pass

        def removeAllJobOriginalFileLinkSet(self, targets, current=None):
            pass

        def clearOriginalFileLinks(self, current=None):
            pass

        def reloadOriginalFileLinks(self, toCopy, current=None):
            pass

        def getOriginalFileLinksCountPerOwner(self, current=None):
            pass

        def linkOriginalFile(self, addition, current=None):
            pass

        def addJobOriginalFileLinkToBoth(self, link, bothSides, current=None):
            pass

        def findJobOriginalFileLink(self, removal, current=None):
            pass

        def unlinkOriginalFile(self, removal, current=None):
            pass

        def removeJobOriginalFileLinkFromBoth(self, link, bothSides, current=None):
            pass

        def linkedOriginalFileList(self, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_Job)

        __repr__ = __str__

    _M_omero.model.JobPrx = Ice.createTempClass()
    class JobPrx(_M_omero.model.IObjectPrx):

        def getVersion(self, _ctx=None):
            return _M_omero.model.Job._op_getVersion.invoke(self, ((), _ctx))

        def begin_getVersion(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Job._op_getVersion.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getVersion(self, _r):
            return _M_omero.model.Job._op_getVersion.end(self, _r)

        def setVersion(self, theVersion, _ctx=None):
            return _M_omero.model.Job._op_setVersion.invoke(self, ((theVersion, ), _ctx))

        def begin_setVersion(self, theVersion, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Job._op_setVersion.begin(self, ((theVersion, ), _response, _ex, _sent, _ctx))

        def end_setVersion(self, _r):
            return _M_omero.model.Job._op_setVersion.end(self, _r)

        def getUsername(self, _ctx=None):
            return _M_omero.model.Job._op_getUsername.invoke(self, ((), _ctx))

        def begin_getUsername(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Job._op_getUsername.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getUsername(self, _r):
            return _M_omero.model.Job._op_getUsername.end(self, _r)

        def setUsername(self, theUsername, _ctx=None):
            return _M_omero.model.Job._op_setUsername.invoke(self, ((theUsername, ), _ctx))

        def begin_setUsername(self, theUsername, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Job._op_setUsername.begin(self, ((theUsername, ), _response, _ex, _sent, _ctx))

        def end_setUsername(self, _r):
            return _M_omero.model.Job._op_setUsername.end(self, _r)

        def getGroupname(self, _ctx=None):
            return _M_omero.model.Job._op_getGroupname.invoke(self, ((), _ctx))

        def begin_getGroupname(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Job._op_getGroupname.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getGroupname(self, _r):
            return _M_omero.model.Job._op_getGroupname.end(self, _r)

        def setGroupname(self, theGroupname, _ctx=None):
            return _M_omero.model.Job._op_setGroupname.invoke(self, ((theGroupname, ), _ctx))

        def begin_setGroupname(self, theGroupname, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Job._op_setGroupname.begin(self, ((theGroupname, ), _response, _ex, _sent, _ctx))

        def end_setGroupname(self, _r):
            return _M_omero.model.Job._op_setGroupname.end(self, _r)

        def getType(self, _ctx=None):
            return _M_omero.model.Job._op_getType.invoke(self, ((), _ctx))

        def begin_getType(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Job._op_getType.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getType(self, _r):
            return _M_omero.model.Job._op_getType.end(self, _r)

        def setType(self, theType, _ctx=None):
            return _M_omero.model.Job._op_setType.invoke(self, ((theType, ), _ctx))

        def begin_setType(self, theType, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Job._op_setType.begin(self, ((theType, ), _response, _ex, _sent, _ctx))

        def end_setType(self, _r):
            return _M_omero.model.Job._op_setType.end(self, _r)

        def getMessage(self, _ctx=None):
            return _M_omero.model.Job._op_getMessage.invoke(self, ((), _ctx))

        def begin_getMessage(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Job._op_getMessage.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getMessage(self, _r):
            return _M_omero.model.Job._op_getMessage.end(self, _r)

        def setMessage(self, theMessage, _ctx=None):
            return _M_omero.model.Job._op_setMessage.invoke(self, ((theMessage, ), _ctx))

        def begin_setMessage(self, theMessage, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Job._op_setMessage.begin(self, ((theMessage, ), _response, _ex, _sent, _ctx))

        def end_setMessage(self, _r):
            return _M_omero.model.Job._op_setMessage.end(self, _r)

        def getStatus(self, _ctx=None):
            return _M_omero.model.Job._op_getStatus.invoke(self, ((), _ctx))

        def begin_getStatus(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Job._op_getStatus.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getStatus(self, _r):
            return _M_omero.model.Job._op_getStatus.end(self, _r)

        def setStatus(self, theStatus, _ctx=None):
            return _M_omero.model.Job._op_setStatus.invoke(self, ((theStatus, ), _ctx))

        def begin_setStatus(self, theStatus, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Job._op_setStatus.begin(self, ((theStatus, ), _response, _ex, _sent, _ctx))

        def end_setStatus(self, _r):
            return _M_omero.model.Job._op_setStatus.end(self, _r)

        def getSubmitted(self, _ctx=None):
            return _M_omero.model.Job._op_getSubmitted.invoke(self, ((), _ctx))

        def begin_getSubmitted(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Job._op_getSubmitted.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getSubmitted(self, _r):
            return _M_omero.model.Job._op_getSubmitted.end(self, _r)

        def setSubmitted(self, theSubmitted, _ctx=None):
            return _M_omero.model.Job._op_setSubmitted.invoke(self, ((theSubmitted, ), _ctx))

        def begin_setSubmitted(self, theSubmitted, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Job._op_setSubmitted.begin(self, ((theSubmitted, ), _response, _ex, _sent, _ctx))

        def end_setSubmitted(self, _r):
            return _M_omero.model.Job._op_setSubmitted.end(self, _r)

        def getScheduledFor(self, _ctx=None):
            return _M_omero.model.Job._op_getScheduledFor.invoke(self, ((), _ctx))

        def begin_getScheduledFor(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Job._op_getScheduledFor.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getScheduledFor(self, _r):
            return _M_omero.model.Job._op_getScheduledFor.end(self, _r)

        def setScheduledFor(self, theScheduledFor, _ctx=None):
            return _M_omero.model.Job._op_setScheduledFor.invoke(self, ((theScheduledFor, ), _ctx))

        def begin_setScheduledFor(self, theScheduledFor, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Job._op_setScheduledFor.begin(self, ((theScheduledFor, ), _response, _ex, _sent, _ctx))

        def end_setScheduledFor(self, _r):
            return _M_omero.model.Job._op_setScheduledFor.end(self, _r)

        def getStarted(self, _ctx=None):
            return _M_omero.model.Job._op_getStarted.invoke(self, ((), _ctx))

        def begin_getStarted(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Job._op_getStarted.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getStarted(self, _r):
            return _M_omero.model.Job._op_getStarted.end(self, _r)

        def setStarted(self, theStarted, _ctx=None):
            return _M_omero.model.Job._op_setStarted.invoke(self, ((theStarted, ), _ctx))

        def begin_setStarted(self, theStarted, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Job._op_setStarted.begin(self, ((theStarted, ), _response, _ex, _sent, _ctx))

        def end_setStarted(self, _r):
            return _M_omero.model.Job._op_setStarted.end(self, _r)

        def getFinished(self, _ctx=None):
            return _M_omero.model.Job._op_getFinished.invoke(self, ((), _ctx))

        def begin_getFinished(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Job._op_getFinished.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getFinished(self, _r):
            return _M_omero.model.Job._op_getFinished.end(self, _r)

        def setFinished(self, theFinished, _ctx=None):
            return _M_omero.model.Job._op_setFinished.invoke(self, ((theFinished, ), _ctx))

        def begin_setFinished(self, theFinished, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Job._op_setFinished.begin(self, ((theFinished, ), _response, _ex, _sent, _ctx))

        def end_setFinished(self, _r):
            return _M_omero.model.Job._op_setFinished.end(self, _r)

        def unloadOriginalFileLinks(self, _ctx=None):
            return _M_omero.model.Job._op_unloadOriginalFileLinks.invoke(self, ((), _ctx))

        def begin_unloadOriginalFileLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Job._op_unloadOriginalFileLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_unloadOriginalFileLinks(self, _r):
            return _M_omero.model.Job._op_unloadOriginalFileLinks.end(self, _r)

        def sizeOfOriginalFileLinks(self, _ctx=None):
            return _M_omero.model.Job._op_sizeOfOriginalFileLinks.invoke(self, ((), _ctx))

        def begin_sizeOfOriginalFileLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Job._op_sizeOfOriginalFileLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_sizeOfOriginalFileLinks(self, _r):
            return _M_omero.model.Job._op_sizeOfOriginalFileLinks.end(self, _r)

        def copyOriginalFileLinks(self, _ctx=None):
            return _M_omero.model.Job._op_copyOriginalFileLinks.invoke(self, ((), _ctx))

        def begin_copyOriginalFileLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Job._op_copyOriginalFileLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_copyOriginalFileLinks(self, _r):
            return _M_omero.model.Job._op_copyOriginalFileLinks.end(self, _r)

        def addJobOriginalFileLink(self, target, _ctx=None):
            return _M_omero.model.Job._op_addJobOriginalFileLink.invoke(self, ((target, ), _ctx))

        def begin_addJobOriginalFileLink(self, target, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Job._op_addJobOriginalFileLink.begin(self, ((target, ), _response, _ex, _sent, _ctx))

        def end_addJobOriginalFileLink(self, _r):
            return _M_omero.model.Job._op_addJobOriginalFileLink.end(self, _r)

        def addAllJobOriginalFileLinkSet(self, targets, _ctx=None):
            return _M_omero.model.Job._op_addAllJobOriginalFileLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_addAllJobOriginalFileLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Job._op_addAllJobOriginalFileLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_addAllJobOriginalFileLinkSet(self, _r):
            return _M_omero.model.Job._op_addAllJobOriginalFileLinkSet.end(self, _r)

        def removeJobOriginalFileLink(self, theTarget, _ctx=None):
            return _M_omero.model.Job._op_removeJobOriginalFileLink.invoke(self, ((theTarget, ), _ctx))

        def begin_removeJobOriginalFileLink(self, theTarget, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Job._op_removeJobOriginalFileLink.begin(self, ((theTarget, ), _response, _ex, _sent, _ctx))

        def end_removeJobOriginalFileLink(self, _r):
            return _M_omero.model.Job._op_removeJobOriginalFileLink.end(self, _r)

        def removeAllJobOriginalFileLinkSet(self, targets, _ctx=None):
            return _M_omero.model.Job._op_removeAllJobOriginalFileLinkSet.invoke(self, ((targets, ), _ctx))

        def begin_removeAllJobOriginalFileLinkSet(self, targets, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Job._op_removeAllJobOriginalFileLinkSet.begin(self, ((targets, ), _response, _ex, _sent, _ctx))

        def end_removeAllJobOriginalFileLinkSet(self, _r):
            return _M_omero.model.Job._op_removeAllJobOriginalFileLinkSet.end(self, _r)

        def clearOriginalFileLinks(self, _ctx=None):
            return _M_omero.model.Job._op_clearOriginalFileLinks.invoke(self, ((), _ctx))

        def begin_clearOriginalFileLinks(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Job._op_clearOriginalFileLinks.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_clearOriginalFileLinks(self, _r):
            return _M_omero.model.Job._op_clearOriginalFileLinks.end(self, _r)

        def reloadOriginalFileLinks(self, toCopy, _ctx=None):
            return _M_omero.model.Job._op_reloadOriginalFileLinks.invoke(self, ((toCopy, ), _ctx))

        def begin_reloadOriginalFileLinks(self, toCopy, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Job._op_reloadOriginalFileLinks.begin(self, ((toCopy, ), _response, _ex, _sent, _ctx))

        def end_reloadOriginalFileLinks(self, _r):
            return _M_omero.model.Job._op_reloadOriginalFileLinks.end(self, _r)

        def getOriginalFileLinksCountPerOwner(self, _ctx=None):
            return _M_omero.model.Job._op_getOriginalFileLinksCountPerOwner.invoke(self, ((), _ctx))

        def begin_getOriginalFileLinksCountPerOwner(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Job._op_getOriginalFileLinksCountPerOwner.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getOriginalFileLinksCountPerOwner(self, _r):
            return _M_omero.model.Job._op_getOriginalFileLinksCountPerOwner.end(self, _r)

        def linkOriginalFile(self, addition, _ctx=None):
            return _M_omero.model.Job._op_linkOriginalFile.invoke(self, ((addition, ), _ctx))

        def begin_linkOriginalFile(self, addition, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Job._op_linkOriginalFile.begin(self, ((addition, ), _response, _ex, _sent, _ctx))

        def end_linkOriginalFile(self, _r):
            return _M_omero.model.Job._op_linkOriginalFile.end(self, _r)

        def addJobOriginalFileLinkToBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.Job._op_addJobOriginalFileLinkToBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_addJobOriginalFileLinkToBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Job._op_addJobOriginalFileLinkToBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_addJobOriginalFileLinkToBoth(self, _r):
            return _M_omero.model.Job._op_addJobOriginalFileLinkToBoth.end(self, _r)

        def findJobOriginalFileLink(self, removal, _ctx=None):
            return _M_omero.model.Job._op_findJobOriginalFileLink.invoke(self, ((removal, ), _ctx))

        def begin_findJobOriginalFileLink(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Job._op_findJobOriginalFileLink.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_findJobOriginalFileLink(self, _r):
            return _M_omero.model.Job._op_findJobOriginalFileLink.end(self, _r)

        def unlinkOriginalFile(self, removal, _ctx=None):
            return _M_omero.model.Job._op_unlinkOriginalFile.invoke(self, ((removal, ), _ctx))

        def begin_unlinkOriginalFile(self, removal, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Job._op_unlinkOriginalFile.begin(self, ((removal, ), _response, _ex, _sent, _ctx))

        def end_unlinkOriginalFile(self, _r):
            return _M_omero.model.Job._op_unlinkOriginalFile.end(self, _r)

        def removeJobOriginalFileLinkFromBoth(self, link, bothSides, _ctx=None):
            return _M_omero.model.Job._op_removeJobOriginalFileLinkFromBoth.invoke(self, ((link, bothSides), _ctx))

        def begin_removeJobOriginalFileLinkFromBoth(self, link, bothSides, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Job._op_removeJobOriginalFileLinkFromBoth.begin(self, ((link, bothSides), _response, _ex, _sent, _ctx))

        def end_removeJobOriginalFileLinkFromBoth(self, _r):
            return _M_omero.model.Job._op_removeJobOriginalFileLinkFromBoth.end(self, _r)

        def linkedOriginalFileList(self, _ctx=None):
            return _M_omero.model.Job._op_linkedOriginalFileList.invoke(self, ((), _ctx))

        def begin_linkedOriginalFileList(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Job._op_linkedOriginalFileList.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_linkedOriginalFileList(self, _r):
            return _M_omero.model.Job._op_linkedOriginalFileList.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.JobPrx.ice_checkedCast(proxy, '::omero::model::Job', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.JobPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::Job'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_JobPrx = IcePy.defineProxy('::omero::model::Job', JobPrx)

    _M_omero.model._t_Job = IcePy.declareClass('::omero::model::Job')

    _M_omero.model._t_Job = IcePy.defineClass('::omero::model::Job', Job, -1, (), True, False, _M_omero.model._t_IObject, (), (
        ('_version', (), _M_omero._t_RInt, False, 0),
        ('_username', (), _M_omero._t_RString, False, 0),
        ('_groupname', (), _M_omero._t_RString, False, 0),
        ('_type', (), _M_omero._t_RString, False, 0),
        ('_message', (), _M_omero._t_RString, False, 0),
        ('_status', (), _M_omero.model._t_JobStatus, False, 0),
        ('_submitted', (), _M_omero._t_RTime, False, 0),
        ('_scheduledFor', (), _M_omero._t_RTime, False, 0),
        ('_started', (), _M_omero._t_RTime, False, 0),
        ('_finished', (), _M_omero._t_RTime, False, 0),
        ('_originalFileLinksSeq', (), _M_omero.model._t_JobOriginalFileLinksSeq, False, 0),
        ('_originalFileLinksLoaded', (), IcePy._t_bool, False, 0),
        ('_originalFileLinksCountPerOwner', (), _M_omero.sys._t_CountMap, False, 0)
    ))
    Job._ice_type = _M_omero.model._t_Job

    Job._op_getVersion = IcePy.Operation('getVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    Job._op_setVersion = IcePy.Operation('setVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    Job._op_getUsername = IcePy.Operation('getUsername', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Job._op_setUsername = IcePy.Operation('setUsername', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Job._op_getGroupname = IcePy.Operation('getGroupname', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Job._op_setGroupname = IcePy.Operation('setGroupname', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Job._op_getType = IcePy.Operation('getType', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Job._op_setType = IcePy.Operation('setType', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Job._op_getMessage = IcePy.Operation('getMessage', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Job._op_setMessage = IcePy.Operation('setMessage', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    Job._op_getStatus = IcePy.Operation('getStatus', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_JobStatus, False, 0), ())
    Job._op_setStatus = IcePy.Operation('setStatus', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_JobStatus, False, 0),), (), None, ())
    Job._op_getSubmitted = IcePy.Operation('getSubmitted', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RTime, False, 0), ())
    Job._op_setSubmitted = IcePy.Operation('setSubmitted', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RTime, False, 0),), (), None, ())
    Job._op_getScheduledFor = IcePy.Operation('getScheduledFor', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RTime, False, 0), ())
    Job._op_setScheduledFor = IcePy.Operation('setScheduledFor', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RTime, False, 0),), (), None, ())
    Job._op_getStarted = IcePy.Operation('getStarted', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RTime, False, 0), ())
    Job._op_setStarted = IcePy.Operation('setStarted', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RTime, False, 0),), (), None, ())
    Job._op_getFinished = IcePy.Operation('getFinished', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RTime, False, 0), ())
    Job._op_setFinished = IcePy.Operation('setFinished', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RTime, False, 0),), (), None, ())
    Job._op_unloadOriginalFileLinks = IcePy.Operation('unloadOriginalFileLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Job._op_sizeOfOriginalFileLinks = IcePy.Operation('sizeOfOriginalFileLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), IcePy._t_int, False, 0), ())
    Job._op_copyOriginalFileLinks = IcePy.Operation('copyOriginalFileLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_JobOriginalFileLinksSeq, False, 0), ())
    Job._op_addJobOriginalFileLink = IcePy.Operation('addJobOriginalFileLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_JobOriginalFileLink, False, 0),), (), None, ())
    Job._op_addAllJobOriginalFileLinkSet = IcePy.Operation('addAllJobOriginalFileLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_JobOriginalFileLinksSeq, False, 0),), (), None, ())
    Job._op_removeJobOriginalFileLink = IcePy.Operation('removeJobOriginalFileLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_JobOriginalFileLink, False, 0),), (), None, ())
    Job._op_removeAllJobOriginalFileLinkSet = IcePy.Operation('removeAllJobOriginalFileLinkSet', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_JobOriginalFileLinksSeq, False, 0),), (), None, ())
    Job._op_clearOriginalFileLinks = IcePy.Operation('clearOriginalFileLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), None, ())
    Job._op_reloadOriginalFileLinks = IcePy.Operation('reloadOriginalFileLinks', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Job, False, 0),), (), None, ())
    Job._op_getOriginalFileLinksCountPerOwner = IcePy.Operation('getOriginalFileLinksCountPerOwner', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.sys._t_CountMap, False, 0), ())
    Job._op_linkOriginalFile = IcePy.Operation('linkOriginalFile', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_OriginalFile, False, 0),), (), ((), _M_omero.model._t_JobOriginalFileLink, False, 0), ())
    Job._op_addJobOriginalFileLinkToBoth = IcePy.Operation('addJobOriginalFileLinkToBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_JobOriginalFileLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    Job._op_findJobOriginalFileLink = IcePy.Operation('findJobOriginalFileLink', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_OriginalFile, False, 0),), (), ((), _M_omero.model._t_JobOriginalFileLinksSeq, False, 0), ())
    Job._op_unlinkOriginalFile = IcePy.Operation('unlinkOriginalFile', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_OriginalFile, False, 0),), (), None, ())
    Job._op_removeJobOriginalFileLinkFromBoth = IcePy.Operation('removeJobOriginalFileLinkFromBoth', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_JobOriginalFileLink, False, 0), ((), IcePy._t_bool, False, 0)), (), None, ())
    Job._op_linkedOriginalFileList = IcePy.Operation('linkedOriginalFileList', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_JobLinkedOriginalFileSeq, False, 0), ())

    _M_omero.model.Job = Job
    del Job

    _M_omero.model.JobPrx = JobPrx
    del JobPrx

# End of module omero.model

__name__ = 'omero'

# End of module omero
