#!/usr/bin/env python
# -*- coding: utf-8 -*-
#
#   Copyright 2010 Glencoe Software, Inc. All rights reserved.
#   Use is subject to license terms supplied in LICENSE.txt
#

import IceImport
IceImport.load("omero_FS_ice")
IceImport.load("omero_Scripts_ice")
IceImport.load("omero_SharedResources_ice")
IceImport.load("omero_Tables_ice")
