# Generated by slice2py - DO NOT EDIT!
#

import Ice
Ice.updateModule("omero.model.enums")

# Modules:
import omero_model_AcquisitionMode_ice
import omero_model_AdminPrivilege_ice
import omero_model_ArcType_ice
import omero_model_Binning_ice
import omero_model_ChecksumAlgorithm_ice
import omero_model_ContrastMethod_ice
import omero_model_Correction_ice
import omero_model_DetectorType_ice
import omero_model_DimensionOrder_ice
import omero_model_EventType_ice
import omero_model_ExperimentType_ice
import omero_model_Family_ice
import omero_model_FilamentType_ice
import omero_model_FilterType_ice
import omero_model_Format_ice
import omero_model_Illumination_ice
import omero_model_Immersion_ice
import omero_model_JobStatus_ice
import omero_model_LaserMedium_ice
import omero_model_LaserType_ice
import omero_model_Medium_ice
import omero_model_MicrobeamManipulationType_ice
import omero_model_MicroscopeType_ice
import omero_model_PhotometricInterpretation_ice
import omero_model_PixelsType_ice
import omero_model_ProjectionAxis_ice
import omero_model_ProjectionType_ice
import omero_model_Pulse_ice
import omero_model_RenderingModel_ice
import omero_model_Units_ice

# Submodules:
