# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `Ellipse.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice
import omero_model_Shape_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'Roi' not in _M_omero.model.__dict__:
    _M_omero.model._t_Roi = IcePy.declareClass('::omero::model::Roi')
    _M_omero.model._t_RoiPrx = IcePy.declareProxy('::omero::model::Roi')

if 'AffineTransform' not in _M_omero.model.__dict__:
    _M_omero.model._t_AffineTransform = IcePy.declareClass('::omero::model::AffineTransform')
    _M_omero.model._t_AffineTransformPrx = IcePy.declareProxy('::omero::model::AffineTransform')

if 'Length' not in _M_omero.model.__dict__:
    _M_omero.model._t_Length = IcePy.declareClass('::omero::model::Length')
    _M_omero.model._t_LengthPrx = IcePy.declareProxy('::omero::model::Length')

if 'ShapeAnnotationLink' not in _M_omero.model.__dict__:
    _M_omero.model._t_ShapeAnnotationLink = IcePy.declareClass('::omero::model::ShapeAnnotationLink')
    _M_omero.model._t_ShapeAnnotationLinkPrx = IcePy.declareProxy('::omero::model::ShapeAnnotationLink')

if 'Annotation' not in _M_omero.model.__dict__:
    _M_omero.model._t_Annotation = IcePy.declareClass('::omero::model::Annotation')
    _M_omero.model._t_AnnotationPrx = IcePy.declareProxy('::omero::model::Annotation')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if 'Ellipse' not in _M_omero.model.__dict__:
    _M_omero.model.Ellipse = Ice.createTempClass()
    class Ellipse(_M_omero.model.Shape):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _theZ=None, _theT=None, _theC=None, _roi=None, _locked=None, _transform=None, _fillColor=None, _fillRule=None, _strokeColor=None, _strokeDashArray=None, _strokeWidth=None, _fontFamily=None, _fontSize=None, _fontStyle=None, _annotationLinksSeq=None, _annotationLinksLoaded=False, _annotationLinksCountPerOwner=None, _x=None, _y=None, _radiusX=None, _radiusY=None, _textValue=None):
            if Ice.getType(self) == _M_omero.model.Ellipse:
                raise RuntimeError('omero.model.Ellipse is an abstract class')
            _M_omero.model.Shape.__init__(self, _id, _details, _loaded, _version, _theZ, _theT, _theC, _roi, _locked, _transform, _fillColor, _fillRule, _strokeColor, _strokeDashArray, _strokeWidth, _fontFamily, _fontSize, _fontStyle, _annotationLinksSeq, _annotationLinksLoaded, _annotationLinksCountPerOwner)
            self._x = _x
            self._y = _y
            self._radiusX = _radiusX
            self._radiusY = _radiusY
            self._textValue = _textValue

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::Ellipse', '::omero::model::IObject', '::omero::model::Shape')

        def ice_id(self, current=None):
            return '::omero::model::Ellipse'

        def ice_staticId():
            return '::omero::model::Ellipse'
        ice_staticId = staticmethod(ice_staticId)

        def getX(self, current=None):
            pass

        def setX(self, theX, current=None):
            pass

        def getY(self, current=None):
            pass

        def setY(self, theY, current=None):
            pass

        def getRadiusX(self, current=None):
            pass

        def setRadiusX(self, theRadiusX, current=None):
            pass

        def getRadiusY(self, current=None):
            pass

        def setRadiusY(self, theRadiusY, current=None):
            pass

        def getTextValue(self, current=None):
            pass

        def setTextValue(self, theTextValue, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_Ellipse)

        __repr__ = __str__

    _M_omero.model.EllipsePrx = Ice.createTempClass()
    class EllipsePrx(_M_omero.model.ShapePrx):

        def getX(self, _ctx=None):
            return _M_omero.model.Ellipse._op_getX.invoke(self, ((), _ctx))

        def begin_getX(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Ellipse._op_getX.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getX(self, _r):
            return _M_omero.model.Ellipse._op_getX.end(self, _r)

        def setX(self, theX, _ctx=None):
            return _M_omero.model.Ellipse._op_setX.invoke(self, ((theX, ), _ctx))

        def begin_setX(self, theX, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Ellipse._op_setX.begin(self, ((theX, ), _response, _ex, _sent, _ctx))

        def end_setX(self, _r):
            return _M_omero.model.Ellipse._op_setX.end(self, _r)

        def getY(self, _ctx=None):
            return _M_omero.model.Ellipse._op_getY.invoke(self, ((), _ctx))

        def begin_getY(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Ellipse._op_getY.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getY(self, _r):
            return _M_omero.model.Ellipse._op_getY.end(self, _r)

        def setY(self, theY, _ctx=None):
            return _M_omero.model.Ellipse._op_setY.invoke(self, ((theY, ), _ctx))

        def begin_setY(self, theY, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Ellipse._op_setY.begin(self, ((theY, ), _response, _ex, _sent, _ctx))

        def end_setY(self, _r):
            return _M_omero.model.Ellipse._op_setY.end(self, _r)

        def getRadiusX(self, _ctx=None):
            return _M_omero.model.Ellipse._op_getRadiusX.invoke(self, ((), _ctx))

        def begin_getRadiusX(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Ellipse._op_getRadiusX.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getRadiusX(self, _r):
            return _M_omero.model.Ellipse._op_getRadiusX.end(self, _r)

        def setRadiusX(self, theRadiusX, _ctx=None):
            return _M_omero.model.Ellipse._op_setRadiusX.invoke(self, ((theRadiusX, ), _ctx))

        def begin_setRadiusX(self, theRadiusX, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Ellipse._op_setRadiusX.begin(self, ((theRadiusX, ), _response, _ex, _sent, _ctx))

        def end_setRadiusX(self, _r):
            return _M_omero.model.Ellipse._op_setRadiusX.end(self, _r)

        def getRadiusY(self, _ctx=None):
            return _M_omero.model.Ellipse._op_getRadiusY.invoke(self, ((), _ctx))

        def begin_getRadiusY(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Ellipse._op_getRadiusY.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getRadiusY(self, _r):
            return _M_omero.model.Ellipse._op_getRadiusY.end(self, _r)

        def setRadiusY(self, theRadiusY, _ctx=None):
            return _M_omero.model.Ellipse._op_setRadiusY.invoke(self, ((theRadiusY, ), _ctx))

        def begin_setRadiusY(self, theRadiusY, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Ellipse._op_setRadiusY.begin(self, ((theRadiusY, ), _response, _ex, _sent, _ctx))

        def end_setRadiusY(self, _r):
            return _M_omero.model.Ellipse._op_setRadiusY.end(self, _r)

        def getTextValue(self, _ctx=None):
            return _M_omero.model.Ellipse._op_getTextValue.invoke(self, ((), _ctx))

        def begin_getTextValue(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Ellipse._op_getTextValue.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getTextValue(self, _r):
            return _M_omero.model.Ellipse._op_getTextValue.end(self, _r)

        def setTextValue(self, theTextValue, _ctx=None):
            return _M_omero.model.Ellipse._op_setTextValue.invoke(self, ((theTextValue, ), _ctx))

        def begin_setTextValue(self, theTextValue, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Ellipse._op_setTextValue.begin(self, ((theTextValue, ), _response, _ex, _sent, _ctx))

        def end_setTextValue(self, _r):
            return _M_omero.model.Ellipse._op_setTextValue.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.EllipsePrx.ice_checkedCast(proxy, '::omero::model::Ellipse', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.EllipsePrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::Ellipse'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_EllipsePrx = IcePy.defineProxy('::omero::model::Ellipse', EllipsePrx)

    _M_omero.model._t_Ellipse = IcePy.declareClass('::omero::model::Ellipse')

    _M_omero.model._t_Ellipse = IcePy.defineClass('::omero::model::Ellipse', Ellipse, -1, (), True, False, _M_omero.model._t_Shape, (), (
        ('_x', (), _M_omero._t_RDouble, False, 0),
        ('_y', (), _M_omero._t_RDouble, False, 0),
        ('_radiusX', (), _M_omero._t_RDouble, False, 0),
        ('_radiusY', (), _M_omero._t_RDouble, False, 0),
        ('_textValue', (), _M_omero._t_RString, False, 0)
    ))
    Ellipse._ice_type = _M_omero.model._t_Ellipse

    Ellipse._op_getX = IcePy.Operation('getX', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RDouble, False, 0), ())
    Ellipse._op_setX = IcePy.Operation('setX', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RDouble, False, 0),), (), None, ())
    Ellipse._op_getY = IcePy.Operation('getY', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RDouble, False, 0), ())
    Ellipse._op_setY = IcePy.Operation('setY', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RDouble, False, 0),), (), None, ())
    Ellipse._op_getRadiusX = IcePy.Operation('getRadiusX', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RDouble, False, 0), ())
    Ellipse._op_setRadiusX = IcePy.Operation('setRadiusX', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RDouble, False, 0),), (), None, ())
    Ellipse._op_getRadiusY = IcePy.Operation('getRadiusY', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RDouble, False, 0), ())
    Ellipse._op_setRadiusY = IcePy.Operation('setRadiusY', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RDouble, False, 0),), (), None, ())
    Ellipse._op_getTextValue = IcePy.Operation('getTextValue', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    Ellipse._op_setTextValue = IcePy.Operation('setTextValue', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())

    _M_omero.model.Ellipse = Ellipse
    del Ellipse

    _M_omero.model.EllipsePrx = EllipsePrx
    del EllipsePrx

# End of module omero.model

__name__ = 'omero'

# End of module omero
