# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `ProjectionDef.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'RenderingDef' not in _M_omero.model.__dict__:
    _M_omero.model._t_RenderingDef = IcePy.declareClass('::omero::model::RenderingDef')
    _M_omero.model._t_RenderingDefPrx = IcePy.declareProxy('::omero::model::RenderingDef')

if 'ProjectionAxis' not in _M_omero.model.__dict__:
    _M_omero.model._t_ProjectionAxis = IcePy.declareClass('::omero::model::ProjectionAxis')
    _M_omero.model._t_ProjectionAxisPrx = IcePy.declareProxy('::omero::model::ProjectionAxis')

if 'ProjectionType' not in _M_omero.model.__dict__:
    _M_omero.model._t_ProjectionType = IcePy.declareClass('::omero::model::ProjectionType')
    _M_omero.model._t_ProjectionTypePrx = IcePy.declareProxy('::omero::model::ProjectionType')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if 'ProjectionDef' not in _M_omero.model.__dict__:
    _M_omero.model.ProjectionDef = Ice.createTempClass()
    class ProjectionDef(_M_omero.model.IObject):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _renderingDef=None, _axis=None, _type=None, _active=None, _startPlane=None, _endPlane=None, _stepping=None):
            if Ice.getType(self) == _M_omero.model.ProjectionDef:
                raise RuntimeError('omero.model.ProjectionDef is an abstract class')
            _M_omero.model.IObject.__init__(self, _id, _details, _loaded)
            self._version = _version
            self._renderingDef = _renderingDef
            self._axis = _axis
            self._type = _type
            self._active = _active
            self._startPlane = _startPlane
            self._endPlane = _endPlane
            self._stepping = _stepping

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::IObject', '::omero::model::ProjectionDef')

        def ice_id(self, current=None):
            return '::omero::model::ProjectionDef'

        def ice_staticId():
            return '::omero::model::ProjectionDef'
        ice_staticId = staticmethod(ice_staticId)

        def getVersion(self, current=None):
            pass

        def setVersion(self, theVersion, current=None):
            pass

        def getRenderingDef(self, current=None):
            pass

        def setRenderingDef(self, theRenderingDef, current=None):
            pass

        def getAxis(self, current=None):
            pass

        def setAxis(self, theAxis, current=None):
            pass

        def getType(self, current=None):
            pass

        def setType(self, theType, current=None):
            pass

        def getActive(self, current=None):
            pass

        def setActive(self, theActive, current=None):
            pass

        def getStartPlane(self, current=None):
            pass

        def setStartPlane(self, theStartPlane, current=None):
            pass

        def getEndPlane(self, current=None):
            pass

        def setEndPlane(self, theEndPlane, current=None):
            pass

        def getStepping(self, current=None):
            pass

        def setStepping(self, theStepping, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_ProjectionDef)

        __repr__ = __str__

    _M_omero.model.ProjectionDefPrx = Ice.createTempClass()
    class ProjectionDefPrx(_M_omero.model.IObjectPrx):

        def getVersion(self, _ctx=None):
            return _M_omero.model.ProjectionDef._op_getVersion.invoke(self, ((), _ctx))

        def begin_getVersion(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ProjectionDef._op_getVersion.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getVersion(self, _r):
            return _M_omero.model.ProjectionDef._op_getVersion.end(self, _r)

        def setVersion(self, theVersion, _ctx=None):
            return _M_omero.model.ProjectionDef._op_setVersion.invoke(self, ((theVersion, ), _ctx))

        def begin_setVersion(self, theVersion, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ProjectionDef._op_setVersion.begin(self, ((theVersion, ), _response, _ex, _sent, _ctx))

        def end_setVersion(self, _r):
            return _M_omero.model.ProjectionDef._op_setVersion.end(self, _r)

        def getRenderingDef(self, _ctx=None):
            return _M_omero.model.ProjectionDef._op_getRenderingDef.invoke(self, ((), _ctx))

        def begin_getRenderingDef(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ProjectionDef._op_getRenderingDef.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getRenderingDef(self, _r):
            return _M_omero.model.ProjectionDef._op_getRenderingDef.end(self, _r)

        def setRenderingDef(self, theRenderingDef, _ctx=None):
            return _M_omero.model.ProjectionDef._op_setRenderingDef.invoke(self, ((theRenderingDef, ), _ctx))

        def begin_setRenderingDef(self, theRenderingDef, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ProjectionDef._op_setRenderingDef.begin(self, ((theRenderingDef, ), _response, _ex, _sent, _ctx))

        def end_setRenderingDef(self, _r):
            return _M_omero.model.ProjectionDef._op_setRenderingDef.end(self, _r)

        def getAxis(self, _ctx=None):
            return _M_omero.model.ProjectionDef._op_getAxis.invoke(self, ((), _ctx))

        def begin_getAxis(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ProjectionDef._op_getAxis.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getAxis(self, _r):
            return _M_omero.model.ProjectionDef._op_getAxis.end(self, _r)

        def setAxis(self, theAxis, _ctx=None):
            return _M_omero.model.ProjectionDef._op_setAxis.invoke(self, ((theAxis, ), _ctx))

        def begin_setAxis(self, theAxis, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ProjectionDef._op_setAxis.begin(self, ((theAxis, ), _response, _ex, _sent, _ctx))

        def end_setAxis(self, _r):
            return _M_omero.model.ProjectionDef._op_setAxis.end(self, _r)

        def getType(self, _ctx=None):
            return _M_omero.model.ProjectionDef._op_getType.invoke(self, ((), _ctx))

        def begin_getType(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ProjectionDef._op_getType.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getType(self, _r):
            return _M_omero.model.ProjectionDef._op_getType.end(self, _r)

        def setType(self, theType, _ctx=None):
            return _M_omero.model.ProjectionDef._op_setType.invoke(self, ((theType, ), _ctx))

        def begin_setType(self, theType, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ProjectionDef._op_setType.begin(self, ((theType, ), _response, _ex, _sent, _ctx))

        def end_setType(self, _r):
            return _M_omero.model.ProjectionDef._op_setType.end(self, _r)

        def getActive(self, _ctx=None):
            return _M_omero.model.ProjectionDef._op_getActive.invoke(self, ((), _ctx))

        def begin_getActive(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ProjectionDef._op_getActive.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getActive(self, _r):
            return _M_omero.model.ProjectionDef._op_getActive.end(self, _r)

        def setActive(self, theActive, _ctx=None):
            return _M_omero.model.ProjectionDef._op_setActive.invoke(self, ((theActive, ), _ctx))

        def begin_setActive(self, theActive, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ProjectionDef._op_setActive.begin(self, ((theActive, ), _response, _ex, _sent, _ctx))

        def end_setActive(self, _r):
            return _M_omero.model.ProjectionDef._op_setActive.end(self, _r)

        def getStartPlane(self, _ctx=None):
            return _M_omero.model.ProjectionDef._op_getStartPlane.invoke(self, ((), _ctx))

        def begin_getStartPlane(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ProjectionDef._op_getStartPlane.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getStartPlane(self, _r):
            return _M_omero.model.ProjectionDef._op_getStartPlane.end(self, _r)

        def setStartPlane(self, theStartPlane, _ctx=None):
            return _M_omero.model.ProjectionDef._op_setStartPlane.invoke(self, ((theStartPlane, ), _ctx))

        def begin_setStartPlane(self, theStartPlane, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ProjectionDef._op_setStartPlane.begin(self, ((theStartPlane, ), _response, _ex, _sent, _ctx))

        def end_setStartPlane(self, _r):
            return _M_omero.model.ProjectionDef._op_setStartPlane.end(self, _r)

        def getEndPlane(self, _ctx=None):
            return _M_omero.model.ProjectionDef._op_getEndPlane.invoke(self, ((), _ctx))

        def begin_getEndPlane(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ProjectionDef._op_getEndPlane.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getEndPlane(self, _r):
            return _M_omero.model.ProjectionDef._op_getEndPlane.end(self, _r)

        def setEndPlane(self, theEndPlane, _ctx=None):
            return _M_omero.model.ProjectionDef._op_setEndPlane.invoke(self, ((theEndPlane, ), _ctx))

        def begin_setEndPlane(self, theEndPlane, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ProjectionDef._op_setEndPlane.begin(self, ((theEndPlane, ), _response, _ex, _sent, _ctx))

        def end_setEndPlane(self, _r):
            return _M_omero.model.ProjectionDef._op_setEndPlane.end(self, _r)

        def getStepping(self, _ctx=None):
            return _M_omero.model.ProjectionDef._op_getStepping.invoke(self, ((), _ctx))

        def begin_getStepping(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ProjectionDef._op_getStepping.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getStepping(self, _r):
            return _M_omero.model.ProjectionDef._op_getStepping.end(self, _r)

        def setStepping(self, theStepping, _ctx=None):
            return _M_omero.model.ProjectionDef._op_setStepping.invoke(self, ((theStepping, ), _ctx))

        def begin_setStepping(self, theStepping, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ProjectionDef._op_setStepping.begin(self, ((theStepping, ), _response, _ex, _sent, _ctx))

        def end_setStepping(self, _r):
            return _M_omero.model.ProjectionDef._op_setStepping.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.ProjectionDefPrx.ice_checkedCast(proxy, '::omero::model::ProjectionDef', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.ProjectionDefPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::ProjectionDef'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_ProjectionDefPrx = IcePy.defineProxy('::omero::model::ProjectionDef', ProjectionDefPrx)

    _M_omero.model._t_ProjectionDef = IcePy.declareClass('::omero::model::ProjectionDef')

    _M_omero.model._t_ProjectionDef = IcePy.defineClass('::omero::model::ProjectionDef', ProjectionDef, -1, (), True, False, _M_omero.model._t_IObject, (), (
        ('_version', (), _M_omero._t_RInt, False, 0),
        ('_renderingDef', (), _M_omero.model._t_RenderingDef, False, 0),
        ('_axis', (), _M_omero.model._t_ProjectionAxis, False, 0),
        ('_type', (), _M_omero.model._t_ProjectionType, False, 0),
        ('_active', (), _M_omero._t_RBool, False, 0),
        ('_startPlane', (), _M_omero._t_RInt, False, 0),
        ('_endPlane', (), _M_omero._t_RInt, False, 0),
        ('_stepping', (), _M_omero._t_RInt, False, 0)
    ))
    ProjectionDef._ice_type = _M_omero.model._t_ProjectionDef

    ProjectionDef._op_getVersion = IcePy.Operation('getVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    ProjectionDef._op_setVersion = IcePy.Operation('setVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    ProjectionDef._op_getRenderingDef = IcePy.Operation('getRenderingDef', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_RenderingDef, False, 0), ())
    ProjectionDef._op_setRenderingDef = IcePy.Operation('setRenderingDef', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_RenderingDef, False, 0),), (), None, ())
    ProjectionDef._op_getAxis = IcePy.Operation('getAxis', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_ProjectionAxis, False, 0), ())
    ProjectionDef._op_setAxis = IcePy.Operation('setAxis', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ProjectionAxis, False, 0),), (), None, ())
    ProjectionDef._op_getType = IcePy.Operation('getType', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_ProjectionType, False, 0), ())
    ProjectionDef._op_setType = IcePy.Operation('setType', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_ProjectionType, False, 0),), (), None, ())
    ProjectionDef._op_getActive = IcePy.Operation('getActive', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RBool, False, 0), ())
    ProjectionDef._op_setActive = IcePy.Operation('setActive', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RBool, False, 0),), (), None, ())
    ProjectionDef._op_getStartPlane = IcePy.Operation('getStartPlane', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    ProjectionDef._op_setStartPlane = IcePy.Operation('setStartPlane', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    ProjectionDef._op_getEndPlane = IcePy.Operation('getEndPlane', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    ProjectionDef._op_setEndPlane = IcePy.Operation('setEndPlane', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    ProjectionDef._op_getStepping = IcePy.Operation('getStepping', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    ProjectionDef._op_setStepping = IcePy.Operation('setStepping', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())

    _M_omero.model.ProjectionDef = ProjectionDef
    del ProjectionDef

    _M_omero.model.ProjectionDefPrx = ProjectionDefPrx
    del ProjectionDefPrx

# End of module omero.model

__name__ = 'omero'

# End of module omero
