# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `DoubleAnnotation.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice
import omero_model_NumericAnnotation_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'AnnotationAnnotationLink' not in _M_omero.model.__dict__:
    _M_omero.model._t_AnnotationAnnotationLink = IcePy.declareClass('::omero::model::AnnotationAnnotationLink')
    _M_omero.model._t_AnnotationAnnotationLinkPrx = IcePy.declareProxy('::omero::model::AnnotationAnnotationLink')

if 'Annotation' not in _M_omero.model.__dict__:
    _M_omero.model._t_Annotation = IcePy.declareClass('::omero::model::Annotation')
    _M_omero.model._t_AnnotationPrx = IcePy.declareProxy('::omero::model::Annotation')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if 'DoubleAnnotation' not in _M_omero.model.__dict__:
    _M_omero.model.DoubleAnnotation = Ice.createTempClass()
    class DoubleAnnotation(_M_omero.model.NumericAnnotation):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _ns=None, _name=None, _description=None, _annotationLinksSeq=None, _annotationLinksLoaded=False, _annotationLinksCountPerOwner=None, _doubleValue=None):
            if Ice.getType(self) == _M_omero.model.DoubleAnnotation:
                raise RuntimeError('omero.model.DoubleAnnotation is an abstract class')
            _M_omero.model.NumericAnnotation.__init__(self, _id, _details, _loaded, _version, _ns, _name, _description, _annotationLinksSeq, _annotationLinksLoaded, _annotationLinksCountPerOwner)
            self._doubleValue = _doubleValue

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::Annotation', '::omero::model::BasicAnnotation', '::omero::model::DoubleAnnotation', '::omero::model::IObject', '::omero::model::NumericAnnotation')

        def ice_id(self, current=None):
            return '::omero::model::DoubleAnnotation'

        def ice_staticId():
            return '::omero::model::DoubleAnnotation'
        ice_staticId = staticmethod(ice_staticId)

        def getDoubleValue(self, current=None):
            pass

        def setDoubleValue(self, theDoubleValue, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_DoubleAnnotation)

        __repr__ = __str__

    _M_omero.model.DoubleAnnotationPrx = Ice.createTempClass()
    class DoubleAnnotationPrx(_M_omero.model.NumericAnnotationPrx):

        def getDoubleValue(self, _ctx=None):
            return _M_omero.model.DoubleAnnotation._op_getDoubleValue.invoke(self, ((), _ctx))

        def begin_getDoubleValue(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.DoubleAnnotation._op_getDoubleValue.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getDoubleValue(self, _r):
            return _M_omero.model.DoubleAnnotation._op_getDoubleValue.end(self, _r)

        def setDoubleValue(self, theDoubleValue, _ctx=None):
            return _M_omero.model.DoubleAnnotation._op_setDoubleValue.invoke(self, ((theDoubleValue, ), _ctx))

        def begin_setDoubleValue(self, theDoubleValue, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.DoubleAnnotation._op_setDoubleValue.begin(self, ((theDoubleValue, ), _response, _ex, _sent, _ctx))

        def end_setDoubleValue(self, _r):
            return _M_omero.model.DoubleAnnotation._op_setDoubleValue.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.DoubleAnnotationPrx.ice_checkedCast(proxy, '::omero::model::DoubleAnnotation', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.DoubleAnnotationPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::DoubleAnnotation'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_DoubleAnnotationPrx = IcePy.defineProxy('::omero::model::DoubleAnnotation', DoubleAnnotationPrx)

    _M_omero.model._t_DoubleAnnotation = IcePy.declareClass('::omero::model::DoubleAnnotation')

    _M_omero.model._t_DoubleAnnotation = IcePy.defineClass('::omero::model::DoubleAnnotation', DoubleAnnotation, -1, (), True, False, _M_omero.model._t_NumericAnnotation, (), (('_doubleValue', (), _M_omero._t_RDouble, False, 0),))
    DoubleAnnotation._ice_type = _M_omero.model._t_DoubleAnnotation

    DoubleAnnotation._op_getDoubleValue = IcePy.Operation('getDoubleValue', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RDouble, False, 0), ())
    DoubleAnnotation._op_setDoubleValue = IcePy.Operation('setDoubleValue', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RDouble, False, 0),), (), None, ())

    _M_omero.model.DoubleAnnotation = DoubleAnnotation
    del DoubleAnnotation

    _M_omero.model.DoubleAnnotationPrx = DoubleAnnotationPrx
    del DoubleAnnotationPrx

# End of module omero.model

__name__ = 'omero'

# End of module omero
