# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `LightSettings.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'Length' not in _M_omero.model.__dict__:
    _M_omero.model._t_Length = IcePy.declareClass('::omero::model::Length')
    _M_omero.model._t_LengthPrx = IcePy.declareProxy('::omero::model::Length')

if 'LightSource' not in _M_omero.model.__dict__:
    _M_omero.model._t_LightSource = IcePy.declareClass('::omero::model::LightSource')
    _M_omero.model._t_LightSourcePrx = IcePy.declareProxy('::omero::model::LightSource')

if 'MicrobeamManipulation' not in _M_omero.model.__dict__:
    _M_omero.model._t_MicrobeamManipulation = IcePy.declareClass('::omero::model::MicrobeamManipulation')
    _M_omero.model._t_MicrobeamManipulationPrx = IcePy.declareProxy('::omero::model::MicrobeamManipulation')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if 'LightSettings' not in _M_omero.model.__dict__:
    _M_omero.model.LightSettings = Ice.createTempClass()
    class LightSettings(_M_omero.model.IObject):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _attenuation=None, _wavelength=None, _lightSource=None, _microbeamManipulation=None):
            if Ice.getType(self) == _M_omero.model.LightSettings:
                raise RuntimeError('omero.model.LightSettings is an abstract class')
            _M_omero.model.IObject.__init__(self, _id, _details, _loaded)
            self._version = _version
            self._attenuation = _attenuation
            self._wavelength = _wavelength
            self._lightSource = _lightSource
            self._microbeamManipulation = _microbeamManipulation

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::IObject', '::omero::model::LightSettings')

        def ice_id(self, current=None):
            return '::omero::model::LightSettings'

        def ice_staticId():
            return '::omero::model::LightSettings'
        ice_staticId = staticmethod(ice_staticId)

        def getVersion(self, current=None):
            pass

        def setVersion(self, theVersion, current=None):
            pass

        def getAttenuation(self, current=None):
            pass

        def setAttenuation(self, theAttenuation, current=None):
            pass

        def getWavelength(self, current=None):
            pass

        def setWavelength(self, theWavelength, current=None):
            pass

        def getLightSource(self, current=None):
            pass

        def setLightSource(self, theLightSource, current=None):
            pass

        def getMicrobeamManipulation(self, current=None):
            pass

        def setMicrobeamManipulation(self, theMicrobeamManipulation, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_LightSettings)

        __repr__ = __str__

    _M_omero.model.LightSettingsPrx = Ice.createTempClass()
    class LightSettingsPrx(_M_omero.model.IObjectPrx):

        def getVersion(self, _ctx=None):
            return _M_omero.model.LightSettings._op_getVersion.invoke(self, ((), _ctx))

        def begin_getVersion(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightSettings._op_getVersion.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getVersion(self, _r):
            return _M_omero.model.LightSettings._op_getVersion.end(self, _r)

        def setVersion(self, theVersion, _ctx=None):
            return _M_omero.model.LightSettings._op_setVersion.invoke(self, ((theVersion, ), _ctx))

        def begin_setVersion(self, theVersion, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightSettings._op_setVersion.begin(self, ((theVersion, ), _response, _ex, _sent, _ctx))

        def end_setVersion(self, _r):
            return _M_omero.model.LightSettings._op_setVersion.end(self, _r)

        def getAttenuation(self, _ctx=None):
            return _M_omero.model.LightSettings._op_getAttenuation.invoke(self, ((), _ctx))

        def begin_getAttenuation(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightSettings._op_getAttenuation.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getAttenuation(self, _r):
            return _M_omero.model.LightSettings._op_getAttenuation.end(self, _r)

        def setAttenuation(self, theAttenuation, _ctx=None):
            return _M_omero.model.LightSettings._op_setAttenuation.invoke(self, ((theAttenuation, ), _ctx))

        def begin_setAttenuation(self, theAttenuation, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightSettings._op_setAttenuation.begin(self, ((theAttenuation, ), _response, _ex, _sent, _ctx))

        def end_setAttenuation(self, _r):
            return _M_omero.model.LightSettings._op_setAttenuation.end(self, _r)

        def getWavelength(self, _ctx=None):
            return _M_omero.model.LightSettings._op_getWavelength.invoke(self, ((), _ctx))

        def begin_getWavelength(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightSettings._op_getWavelength.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getWavelength(self, _r):
            return _M_omero.model.LightSettings._op_getWavelength.end(self, _r)

        def setWavelength(self, theWavelength, _ctx=None):
            return _M_omero.model.LightSettings._op_setWavelength.invoke(self, ((theWavelength, ), _ctx))

        def begin_setWavelength(self, theWavelength, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightSettings._op_setWavelength.begin(self, ((theWavelength, ), _response, _ex, _sent, _ctx))

        def end_setWavelength(self, _r):
            return _M_omero.model.LightSettings._op_setWavelength.end(self, _r)

        def getLightSource(self, _ctx=None):
            return _M_omero.model.LightSettings._op_getLightSource.invoke(self, ((), _ctx))

        def begin_getLightSource(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightSettings._op_getLightSource.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getLightSource(self, _r):
            return _M_omero.model.LightSettings._op_getLightSource.end(self, _r)

        def setLightSource(self, theLightSource, _ctx=None):
            return _M_omero.model.LightSettings._op_setLightSource.invoke(self, ((theLightSource, ), _ctx))

        def begin_setLightSource(self, theLightSource, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightSettings._op_setLightSource.begin(self, ((theLightSource, ), _response, _ex, _sent, _ctx))

        def end_setLightSource(self, _r):
            return _M_omero.model.LightSettings._op_setLightSource.end(self, _r)

        def getMicrobeamManipulation(self, _ctx=None):
            return _M_omero.model.LightSettings._op_getMicrobeamManipulation.invoke(self, ((), _ctx))

        def begin_getMicrobeamManipulation(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightSettings._op_getMicrobeamManipulation.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getMicrobeamManipulation(self, _r):
            return _M_omero.model.LightSettings._op_getMicrobeamManipulation.end(self, _r)

        def setMicrobeamManipulation(self, theMicrobeamManipulation, _ctx=None):
            return _M_omero.model.LightSettings._op_setMicrobeamManipulation.invoke(self, ((theMicrobeamManipulation, ), _ctx))

        def begin_setMicrobeamManipulation(self, theMicrobeamManipulation, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.LightSettings._op_setMicrobeamManipulation.begin(self, ((theMicrobeamManipulation, ), _response, _ex, _sent, _ctx))

        def end_setMicrobeamManipulation(self, _r):
            return _M_omero.model.LightSettings._op_setMicrobeamManipulation.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.LightSettingsPrx.ice_checkedCast(proxy, '::omero::model::LightSettings', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.LightSettingsPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::LightSettings'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_LightSettingsPrx = IcePy.defineProxy('::omero::model::LightSettings', LightSettingsPrx)

    _M_omero.model._t_LightSettings = IcePy.declareClass('::omero::model::LightSettings')

    _M_omero.model._t_LightSettings = IcePy.defineClass('::omero::model::LightSettings', LightSettings, -1, (), True, False, _M_omero.model._t_IObject, (), (
        ('_version', (), _M_omero._t_RInt, False, 0),
        ('_attenuation', (), _M_omero._t_RDouble, False, 0),
        ('_wavelength', (), _M_omero.model._t_Length, False, 0),
        ('_lightSource', (), _M_omero.model._t_LightSource, False, 0),
        ('_microbeamManipulation', (), _M_omero.model._t_MicrobeamManipulation, False, 0)
    ))
    LightSettings._ice_type = _M_omero.model._t_LightSettings

    LightSettings._op_getVersion = IcePy.Operation('getVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    LightSettings._op_setVersion = IcePy.Operation('setVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    LightSettings._op_getAttenuation = IcePy.Operation('getAttenuation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RDouble, False, 0), ())
    LightSettings._op_setAttenuation = IcePy.Operation('setAttenuation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RDouble, False, 0),), (), None, ())
    LightSettings._op_getWavelength = IcePy.Operation('getWavelength', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Length, False, 0), ())
    LightSettings._op_setWavelength = IcePy.Operation('setWavelength', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Length, False, 0),), (), None, ())
    LightSettings._op_getLightSource = IcePy.Operation('getLightSource', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_LightSource, False, 0), ())
    LightSettings._op_setLightSource = IcePy.Operation('setLightSource', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_LightSource, False, 0),), (), None, ())
    LightSettings._op_getMicrobeamManipulation = IcePy.Operation('getMicrobeamManipulation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_MicrobeamManipulation, False, 0), ())
    LightSettings._op_setMicrobeamManipulation = IcePy.Operation('setMicrobeamManipulation', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_MicrobeamManipulation, False, 0),), (), None, ())

    _M_omero.model.LightSettings = LightSettings
    del LightSettings

    _M_omero.model.LightSettingsPrx = LightSettingsPrx
    del LightSettingsPrx

# End of module omero.model

__name__ = 'omero'

# End of module omero
