# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `ObjectiveSettings.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'Medium' not in _M_omero.model.__dict__:
    _M_omero.model._t_Medium = IcePy.declareClass('::omero::model::Medium')
    _M_omero.model._t_MediumPrx = IcePy.declareProxy('::omero::model::Medium')

if 'Objective' not in _M_omero.model.__dict__:
    _M_omero.model._t_Objective = IcePy.declareClass('::omero::model::Objective')
    _M_omero.model._t_ObjectivePrx = IcePy.declareProxy('::omero::model::Objective')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if 'ObjectiveSettings' not in _M_omero.model.__dict__:
    _M_omero.model.ObjectiveSettings = Ice.createTempClass()
    class ObjectiveSettings(_M_omero.model.IObject):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _correctionCollar=None, _medium=None, _refractiveIndex=None, _objective=None):
            if Ice.getType(self) == _M_omero.model.ObjectiveSettings:
                raise RuntimeError('omero.model.ObjectiveSettings is an abstract class')
            _M_omero.model.IObject.__init__(self, _id, _details, _loaded)
            self._version = _version
            self._correctionCollar = _correctionCollar
            self._medium = _medium
            self._refractiveIndex = _refractiveIndex
            self._objective = _objective

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::IObject', '::omero::model::ObjectiveSettings')

        def ice_id(self, current=None):
            return '::omero::model::ObjectiveSettings'

        def ice_staticId():
            return '::omero::model::ObjectiveSettings'
        ice_staticId = staticmethod(ice_staticId)

        def getVersion(self, current=None):
            pass

        def setVersion(self, theVersion, current=None):
            pass

        def getCorrectionCollar(self, current=None):
            pass

        def setCorrectionCollar(self, theCorrectionCollar, current=None):
            pass

        def getMedium(self, current=None):
            pass

        def setMedium(self, theMedium, current=None):
            pass

        def getRefractiveIndex(self, current=None):
            pass

        def setRefractiveIndex(self, theRefractiveIndex, current=None):
            pass

        def getObjective(self, current=None):
            pass

        def setObjective(self, theObjective, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_ObjectiveSettings)

        __repr__ = __str__

    _M_omero.model.ObjectiveSettingsPrx = Ice.createTempClass()
    class ObjectiveSettingsPrx(_M_omero.model.IObjectPrx):

        def getVersion(self, _ctx=None):
            return _M_omero.model.ObjectiveSettings._op_getVersion.invoke(self, ((), _ctx))

        def begin_getVersion(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ObjectiveSettings._op_getVersion.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getVersion(self, _r):
            return _M_omero.model.ObjectiveSettings._op_getVersion.end(self, _r)

        def setVersion(self, theVersion, _ctx=None):
            return _M_omero.model.ObjectiveSettings._op_setVersion.invoke(self, ((theVersion, ), _ctx))

        def begin_setVersion(self, theVersion, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ObjectiveSettings._op_setVersion.begin(self, ((theVersion, ), _response, _ex, _sent, _ctx))

        def end_setVersion(self, _r):
            return _M_omero.model.ObjectiveSettings._op_setVersion.end(self, _r)

        def getCorrectionCollar(self, _ctx=None):
            return _M_omero.model.ObjectiveSettings._op_getCorrectionCollar.invoke(self, ((), _ctx))

        def begin_getCorrectionCollar(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ObjectiveSettings._op_getCorrectionCollar.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getCorrectionCollar(self, _r):
            return _M_omero.model.ObjectiveSettings._op_getCorrectionCollar.end(self, _r)

        def setCorrectionCollar(self, theCorrectionCollar, _ctx=None):
            return _M_omero.model.ObjectiveSettings._op_setCorrectionCollar.invoke(self, ((theCorrectionCollar, ), _ctx))

        def begin_setCorrectionCollar(self, theCorrectionCollar, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ObjectiveSettings._op_setCorrectionCollar.begin(self, ((theCorrectionCollar, ), _response, _ex, _sent, _ctx))

        def end_setCorrectionCollar(self, _r):
            return _M_omero.model.ObjectiveSettings._op_setCorrectionCollar.end(self, _r)

        def getMedium(self, _ctx=None):
            return _M_omero.model.ObjectiveSettings._op_getMedium.invoke(self, ((), _ctx))

        def begin_getMedium(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ObjectiveSettings._op_getMedium.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getMedium(self, _r):
            return _M_omero.model.ObjectiveSettings._op_getMedium.end(self, _r)

        def setMedium(self, theMedium, _ctx=None):
            return _M_omero.model.ObjectiveSettings._op_setMedium.invoke(self, ((theMedium, ), _ctx))

        def begin_setMedium(self, theMedium, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ObjectiveSettings._op_setMedium.begin(self, ((theMedium, ), _response, _ex, _sent, _ctx))

        def end_setMedium(self, _r):
            return _M_omero.model.ObjectiveSettings._op_setMedium.end(self, _r)

        def getRefractiveIndex(self, _ctx=None):
            return _M_omero.model.ObjectiveSettings._op_getRefractiveIndex.invoke(self, ((), _ctx))

        def begin_getRefractiveIndex(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ObjectiveSettings._op_getRefractiveIndex.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getRefractiveIndex(self, _r):
            return _M_omero.model.ObjectiveSettings._op_getRefractiveIndex.end(self, _r)

        def setRefractiveIndex(self, theRefractiveIndex, _ctx=None):
            return _M_omero.model.ObjectiveSettings._op_setRefractiveIndex.invoke(self, ((theRefractiveIndex, ), _ctx))

        def begin_setRefractiveIndex(self, theRefractiveIndex, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ObjectiveSettings._op_setRefractiveIndex.begin(self, ((theRefractiveIndex, ), _response, _ex, _sent, _ctx))

        def end_setRefractiveIndex(self, _r):
            return _M_omero.model.ObjectiveSettings._op_setRefractiveIndex.end(self, _r)

        def getObjective(self, _ctx=None):
            return _M_omero.model.ObjectiveSettings._op_getObjective.invoke(self, ((), _ctx))

        def begin_getObjective(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ObjectiveSettings._op_getObjective.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getObjective(self, _r):
            return _M_omero.model.ObjectiveSettings._op_getObjective.end(self, _r)

        def setObjective(self, theObjective, _ctx=None):
            return _M_omero.model.ObjectiveSettings._op_setObjective.invoke(self, ((theObjective, ), _ctx))

        def begin_setObjective(self, theObjective, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ObjectiveSettings._op_setObjective.begin(self, ((theObjective, ), _response, _ex, _sent, _ctx))

        def end_setObjective(self, _r):
            return _M_omero.model.ObjectiveSettings._op_setObjective.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.ObjectiveSettingsPrx.ice_checkedCast(proxy, '::omero::model::ObjectiveSettings', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.ObjectiveSettingsPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::ObjectiveSettings'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_ObjectiveSettingsPrx = IcePy.defineProxy('::omero::model::ObjectiveSettings', ObjectiveSettingsPrx)

    _M_omero.model._t_ObjectiveSettings = IcePy.declareClass('::omero::model::ObjectiveSettings')

    _M_omero.model._t_ObjectiveSettings = IcePy.defineClass('::omero::model::ObjectiveSettings', ObjectiveSettings, -1, (), True, False, _M_omero.model._t_IObject, (), (
        ('_version', (), _M_omero._t_RInt, False, 0),
        ('_correctionCollar', (), _M_omero._t_RDouble, False, 0),
        ('_medium', (), _M_omero.model._t_Medium, False, 0),
        ('_refractiveIndex', (), _M_omero._t_RDouble, False, 0),
        ('_objective', (), _M_omero.model._t_Objective, False, 0)
    ))
    ObjectiveSettings._ice_type = _M_omero.model._t_ObjectiveSettings

    ObjectiveSettings._op_getVersion = IcePy.Operation('getVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    ObjectiveSettings._op_setVersion = IcePy.Operation('setVersion', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    ObjectiveSettings._op_getCorrectionCollar = IcePy.Operation('getCorrectionCollar', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RDouble, False, 0), ())
    ObjectiveSettings._op_setCorrectionCollar = IcePy.Operation('setCorrectionCollar', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RDouble, False, 0),), (), None, ())
    ObjectiveSettings._op_getMedium = IcePy.Operation('getMedium', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Medium, False, 0), ())
    ObjectiveSettings._op_setMedium = IcePy.Operation('setMedium', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Medium, False, 0),), (), None, ())
    ObjectiveSettings._op_getRefractiveIndex = IcePy.Operation('getRefractiveIndex', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RDouble, False, 0), ())
    ObjectiveSettings._op_setRefractiveIndex = IcePy.Operation('setRefractiveIndex', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RDouble, False, 0),), (), None, ())
    ObjectiveSettings._op_getObjective = IcePy.Operation('getObjective', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Objective, False, 0), ())
    ObjectiveSettings._op_setObjective = IcePy.Operation('setObjective', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Objective, False, 0),), (), None, ())

    _M_omero.model.ObjectiveSettings = ObjectiveSettings
    del ObjectiveSettings

    _M_omero.model.ObjectiveSettingsPrx = ObjectiveSettingsPrx
    del ObjectiveSettingsPrx

# End of module omero.model

__name__ = 'omero'

# End of module omero
